This patch reverses the standard resv logic for channels, making any
channel not listed in a resv{} block banned from the server.

To install:
$ cd /path/to/ircd-ratbox
$ patch -p1 </path/to/2.x-revjupe.diff

- W. Campbell (Hwy)

Index: doc/example.conf
===================================================================
RCS file: /cvsroot/ircd-ratbox/doc/example.conf,v
retrieving revision 7.238
diff -u -r7.238 example.conf
--- doc/example.conf	10 Apr 2004 21:40:57 -0000	7.238
+++ doc/example.conf	13 May 2004 01:19:44 -0000
@@ -480,14 +480,24 @@
 	ip = "192.168.0.0/16";
 };
 
-/* resv {}: nicks and channels users may not use/join (OLD Q:) */
+/* NOTE:  If this line is here, the server was patched to have reverse
+** logic for resv{}.  In this case, any channels NOT listed here are
+** blocked from users.  If 'no_oper_resv' is set to yes in the channels{}
+** block, opers can join any channel.  If not, then opers are restricted
+** the same way.
+**
+** Nick logic remains the same.  Anything listed in a resv{} will prevent
+** that nick from being used.
+*/
 resv {
         /* reason: the reason for the proceeding resv's */
         reason = "There are no services on this network";
 
-	/* resv: the nicks and channels users may not join/use */
+	/* resv: the nicks users may not use */
 	nick = "nickserv";
 	nick = "chanserv";
+
+	/* resv: the channels users MAY use, all others are blocked */
 	channel = "#services";
 
 	/* resv: wildcard masks are also supported in nicks only */
Index: modules/core/m_join.c
===================================================================
RCS file: /cvsroot/ircd-ratbox/modules/core/m_join.c,v
retrieving revision 1.154
diff -u -r1.154 m_join.c
--- modules/core/m_join.c	6 May 2004 22:23:55 -0000	1.154
+++ modules/core/m_join.c	13 May 2004 01:19:44 -0000
@@ -74,7 +74,6 @@
 {
 	static char jbuf[BUFSIZE];
 	struct Channel *chptr = NULL;
-	struct ConfItem *aconf;
 	char *name;
 	char *key = NULL;
 	int i, flags = 0;
@@ -117,14 +116,14 @@
 		}
 
 		/* see if its resv'd */
-		if((aconf = hash_find_resv(name)) && (!IsOper(source_p) || !ConfigChannel.no_oper_resvs))
+		if((hash_find_resv(name) == NULL) && (!IsOper(source_p) || !ConfigChannel.no_oper_resvs))
 		{
 			sendto_one_numeric(source_p, ERR_BADCHANNAME,
 					form_str(ERR_BADCHANNAME), name);
 			sendto_realops_flags(UMODE_SPY, L_ALL,
-					     "User %s (%s@%s) is attempting to join locally juped channel %s (%s)",
+					     "User %s (%s@%s) is attempting to join blocked channel %s",
 					     source_p->name, source_p->username, source_p->host,
-					     name, aconf->passwd);
+					     name);
 			continue;
 		}
 
Index: src/channel.c
===================================================================
RCS file: /cvsroot/ircd-ratbox/src/channel.c,v
retrieving revision 7.417
diff -u -r7.417 channel.c
--- src/channel.c	6 May 2004 22:23:59 -0000	7.417
+++ src/channel.c	13 May 2004 01:19:45 -0000
@@ -592,7 +592,7 @@
 	if(IsServer(source_p))
 		return CAN_SEND_OPV;
 
-	if(MyClient(source_p) && hash_find_resv(chptr->chname) &&
+	if(MyClient(source_p) && (hash_find_resv(chptr->chname) == NULL) &&
 	   (!IsOper(source_p) || !ConfigChannel.no_oper_resvs))
 		return CAN_SEND_NO;
 
